@@ -4,8 +4,8 @@ import requests
 from inspect import currentframe as cf
 
 
-from exceptions import *
-from helpers import CurrenciesIDs, MarketsIDs
+from .exceptions import *
+from .helpers import CurrenciesIDs, MarketsIDs
 
 from logging import Logger
 
@@ -44,7 +44,7 @@ class Bitpin:
 
         self._logger = logger
 
-        self._redis = Redis(**db_params)
+        self._redis = Redis(**db_params, decode_responses=True)
 
         # set timeout from requests_params
         if requests_params is not None:
@@ -168,7 +168,7 @@ class Bitpin:
         else:
             raise StatusCodeError(
                 func_name,
-                f'invalid status code',
+                f'invalid status code {response.text}',
                 url=response.url,
                 status_code=response.status_code,
                 response=response,
